@@ -3,8 +3,8 @@
 
 #include "enums.h"
 
-/* enumerations from "/usr/src/ports/easytag/easytag-2.4.2-1.i686/src/easytag-2.4.2/src/setting.h" */
-#include "/usr/src/ports/easytag/easytag-2.4.2-1.i686/src/easytag-2.4.2/src/setting.h"
+/* enumerations from "/usr/src/ports/easytag/easytag-2.4.3-1.x86_64/src/easytag-2.4.3/src/setting.h" */
+#include "/usr/src/ports/easytag/easytag-2.4.3-1.x86_64/src/easytag-2.4.3/src/setting.h"
 GType
 et_cddb_search_category_get_type (void)
 {
